<?php

namespace App\Repositories\Webprofile;

use App\Models\Webprofile\Slider;
use App\Repositories\Repository;
use Illuminate\Support\Str;
use DataTables;
use Storage;

class SliderRepository extends Repository
{
    protected $model;

    public function __construct(Slider $model)
    {
        $this->model = $model;
    }

    public function get($with = null, $title = null, $orderBy = null)
    {
        return $this->model
            ->when($with, function ($query) use ($with) {
                return $query->with($with);
            })
            ->when($title, function ($query) use ($title) {
                return $query->where('title', 'ilike', '%' . $title . '%');
            })
            ->when($orderBy, function ($query) use ($orderBy) {
                return $query->orderBy($orderBy[0], $orderBy[1]);
            })
            ->get();
    }

    /**
     * Custom Store a newly created resource in Slider.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store($request)
    {
        $setting = webprofilesetting();

        $data = $request->except('_token');
        $data['id'] = Str::uuid()->toString();

        if ($request->hasFile('images')) {
            $cover = $request->file('images');
            $extension = $cover->guessClientExtension();
            $filename = $data['id'] . '.' . $extension;
            if ($setting['external_storage'] == 1) {
                Storage::disk('storage')->put($setting['directory'] . '/slider/' . $filename, file_get_contents($cover->getRealPath()));
            } else {
                Storage::disk('local')->put('public/slider/' . $filename, file_get_contents($cover->getRealPath()));
            }
            $data['images'] = $filename;
        }

        $request['userid_created'] = auth()->user()->id;
        return $this->model->create($data);
    }

    /**
     * Custom Update a resource in Slider.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function update($request, $sModel)
    {
        $setting = webprofilesetting();

        $data = $request->except('_token');

        if ($request->hasFile('images')) {
            $cover = $request->file('images');
            $extension = $cover->guessClientExtension();
            $filename = $sModel->id . '.' . $extension;

            if ($setting['external_storage'] == 1) {
                Storage::disk('storage')->put($setting['directory'] . '/slider/' . $filename, file_get_contents($cover->getRealPath()));
            } else {
                Storage::disk('local')->put('public/slider/' . $filename, file_get_contents($cover->getRealPath()));
            }

            $data['images'] = $filename;
        }

        $data['userid_updated'] = auth()->user()->id;
        return $sModel->update($data);
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  \App\Models\Slider  $slider
     * @return \Illuminate\Http\Response
     */
    public function destroy($sModel)
    {
        $setting = webprofilesetting();

        try {
            if ($sModel->images) {
                if ($setting['external_storage'] == 1) {
                    Storage::disk('storage')->delete($setting['directory'] . '/slider/' . $sModel->images);
                } else {
                    Storage::disk('local')->delete('public/slider/' . $sModel->images);
                }
            }
            $sModel->delete($sModel->id);

            return redirect()->route('sliders.index');
        } catch (\Exception $id) {
            return redirect()->route('sliders.index');
        }
    }

    public function datatable($data)
    {
        $setting = webprofilesetting();

        return DataTables::of($data)
            ->addIndexColumn()
            ->addColumn('action', function ($row) {
                $btn = '<a href="' . url('/webprofile/sliders/' . $row->id . '/edit') . '" data-toggle="tooltip"  data-id="' . $row->id . '" data-original-title="' . trans('label.edit') . '" class="edit btn btn-warning btn-round btn-sm edit">' . trans('label.edit') . '</a>';

                $btn = $btn . ' <a href="javascript:void(0)" data-toggle="tooltip"  data-id="' . $row->id . '" data-original-title="' . trans('label.delete') . '" class="btn btn-danger btn-round btn-sm delete">' . trans('label.delete') . '</a>';

                $btn = $btn . '<br>';

                return $btn;
            })
            ->addColumn('slider', function ($row) use ($setting) {
                if ($setting['external_storage'] == 1) {
                    $str = '<img src="'. $setting['url_static'] . '/' . $setting['directory'] . '/slider/' . $row->images . '" height="100" width="auto">';
                } else {
                    $str = '<img src="'. url('/storage/slider/' . $row->images) . '" height="100" width="auto">';
                }

                return $str;
            })
            ->addColumn('status', function ($row) {
                if ($row->is_active == true) {
                    $str = '<div style="color: green;"><i class="fa fa-check"></i></div>';
                } else {
                    $str = '<div style="color: red;"><i class="fa fa-times"></i></div>';
                }
                return $str;
            })
            ->rawColumns(['action', 'status', 'slider'])
            ->make(true);
    }
}
